## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 4;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond falcon 1

%global srcname openapi-core
%global modname openapi_core

Name:           python-%{srcname}
Version:        0.19.5
Release:        %autorelease
Summary:        OpenAPI client-side and server-side support

License:        BSD-3-Clause
URL:            https://github.com/python-openapi/%{srcname}
Source:         %{pypi_source %{modname}}

# Allow Starlette 0.45 and 0.46
# https://github.com/python-openapi/openapi-core/pull/977
# (Without changes to poetry.lock)
# https://github.com/python-openapi/openapi-core/pull/977/commits/6714b46bbc20933dad48d5907908166cde7fa0c0.
#
# Allow Starlette 0.47
# We can’t offer this upstream until a released version of FastAPI
# officially supports Starlette 0.47.x.
Patch:          openapi-core-0.19.5-starlette-0.47.patch

# Downstream-only: remove werkzeug version pin
#
# Upstream added this to fix
# https://github.com/python-openapi/openapi-core/issues/938, but we have no
# choice: we must use the version that is packaged, even if this breaks things.
Patch:          0001-Downstream-only-remove-werkzeug-version-pin.patch

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  tomcli

# Test dependencies; see [tool.poetry.dev-dependencies], but note that this
# contains both test dependencies and unwanted linters etc., as well as some
# packages that are not directly required by the tests, such as webob and
# strict-rfc3339.
BuildRequires:  python3dist(pytest) >= 8
BuildRequires:  python3dist(pytest-aiohttp)
BuildRequires:  python3dist(responses)

# This is not directly imported in the tests, but is implicitly required for
# some of the Django integration tests.
BuildRequires:  python3dist(djangorestframework)
# This is not directly imported in the tests, but is implicitly required for
# some of the FastAPI and Starlette integration tests.
BuildRequires:  python3dist(httpx)

%global _description %{expand:
Openapi-core is a Python library that adds client-side and server-side
support for the OpenAPI v3.0 and OpenAPI v3.1 specification.}

%description %_description


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %_description


%pyproject_extras_subpkg -n python3-openapi-core aiohttp django %{?with_falcon:falcon} fastapi flask requests starlette


%prep
%autosetup -n %{modname}-%{version} -p1
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i '/^--cov[-=]/d' pyproject.toml
# We cannot respect a SemVer or version range pin on FastAPI; it updates
# frequently, with usually-tiny breaking changes.
sed -r -i \
    -e 's/(fastapi = \{version = ")\^/\1>=/' \
    -e 's/(fastapi = \{version = ".*),<[^"]+/\1/' \
    pyproject.toml
# Erroring on DeprecationWarnings makes sense upstream, but is probably too
# strict for distribution packaging.
#
# This specifically works around:
#
# DeprecationWarning: 'asyncio.get_event_loop_policy' is deprecated and slated
# for removal in Python 3.16
tomcli set pyproject.toml lists delitem \
    tool.pytest.ini_options.filterwarnings error


%generate_buildrequires

%pyproject_buildrequires -x aiohttp -x django %{?with_falcon:-x falcon} -x fastapi -x flask -x requests -x starlette


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files %{modname}


%check
# [Bug]: Regression in Python 3.14: TestImportModelCreate::test_dynamic_model
# https://github.com/python-openapi/openapi-core/issues/1009
k="${k-}${k+ and }not (TestImportModelCreate and test_dynamic_model)"

%if %{without falcon}
ignore="${ignore-} --ignore=tests/integration/contrib/falcon"
%endif

%pytest ${ignore-} -k "${k-}"


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%doc README.md


%changelog
## START: Generated by rpmautospec
* Mon Jun 23 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.5-4
- Work around Python 3.14 issues; fixes RHBZ#2372014
- Do not error on warnings, particularly DeprecationWarning
- Report and skip TestImportModelCreate::test_dynamic_model regression

* Wed Jun 11 2025 Mattia Verga <mattia.verga@proton.me> - 0.19.5-3
- Rebuild for Python 3.14

* Thu May 29 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.5-2
- Allow Starlette 0.47

* Sat Mar 22 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.5-1
- Update to 0.19.5 (close RHBZ#2353933)

* Thu Feb 27 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-9
- Patch to allow Starlette 0.46.x

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sun Dec 29 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-7
- Allow Starlette 0.45.x

* Tue Dec 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-6
- Allow Starlette 0.42.x

* Mon Oct 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-5
- Allow Starlette 0.41.x and FastAPI 0.115.x

* Tue Oct 15 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-4
- Allow Starlette 0.40.x (a security update)

* Sun Sep 29 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-3
- Allow aioitertools 0.12.0 (fix RHBZ#2315548)

* Tue Sep 24 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-2
- Allow Starlette 0.39.x

* Wed Sep 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.4-1
- Update to 0.19.4 (close RHBZ#2309212)

* Thu Aug 15 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.3-1
- Update to 0.19.3 (close RHBZ#2304827)

* Fri Aug 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.2-5
- Allow Starlette 0.38.x

* Mon Jul 29 2024 Tomáš Hrnčiar <thrnciar@redhat.com> - 0.19.2-4
- Revert "Patch for pytest 7; revert this when pytest 8 is packaged"

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sun Jun 30 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.2-1
- Update to 0.19.2 (fedora#2291451)
- Fix FTI with python 3.13 (fedora#2291807)

* Wed Jun 12 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.1-4
- Rebuild for Python 3.13 (fixes Fedora#2291807)

* Mon Apr 22 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.1-3
- Patch for python-aiohttp 3.9.4 and later

* Thu Apr 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.1-2
- Patch for pytest 7; revert this when pytest 8 is packaged

* Thu Apr 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.1-1
- Update to 0.19.1 (close RHBZ#2274391)

* Wed Mar 06 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.0-5
- Allow newer FastAPI versions (close RHBZ#2268092)

* Fri Feb 16 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.0-3
- Accept fastapi 0.109

* Fri Feb 16 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.0-2
- Add fastapi extras

* Fri Feb 16 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.0-1
- Final 0.19.0

* Fri Feb 09 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.19.0~a1-2
- Allow Starlette versions through 0.37.x

* Sat Jan 27 2024 Mattia Verga <mattia.verga@proton.me> - 0.19.0~a1-1
- Update to 0.19.0a1 (fedora#2251107)

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 12 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.18.2-3
- Allow starlette 0.35.1

* Wed Dec 27 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.18.2-2
- Patch to permit starlette 0.32.0

* Mon Nov 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.18.2-1
- Update to 0.18.2 (close RHBZ#2248158)

* Mon Oct 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.18.1-2
- Allow openapi-spec-validator 0.7.x

* Sat Sep 16 2023 Mattia Verga <mattia.verga@proton.me> - 0.18.1-1
- Update to 0.18.1 (fedora#2238939)

* Tue Sep 05 2023 Mattia Verga <mattia.verga@proton.me> - 0.18.0-1
- Update to 0.18.0

* Sat Jul 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-6
- Revert "Disable the “falcon” extra while python-falcon FTI"

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.17.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Jul 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-4
- Rebuild for Python 3.12 (close RHBZ#2220374)

* Sat Jul 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-3
- Disable the “falcon” extra while python-falcon FTI

* Sat Jul 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-2
- Conditionalize the “falcon” extra

* Fri Mar 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-1
- Update to 0.17.1 (close RHBZ#2175776)
- Switch to the PyPI sdist since it now contains tests

* Thu Mar 02 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.6-2
- Update URL

* Thu Mar 02 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.6-1
- Update to 0.16.6 (close RHBZ#2164688)

* Fri Feb 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-2
- Fix tests with current openapi dependencies

* Wed Jan 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-1
- Update to 0.16.5 (close RHBZ#2162400)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Jan 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.4-5
- Add python3-openapi-core+falcon metapackage

* Mon Jan 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.4-4
- Switch to GitHub source and run the tests

* Mon Jan 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.4-3
- Allow openapi-schema-validator 0.4 (fix RHBZ#2160912)

* Thu Dec 22 2022 Mattia Verga <mattia.verga@proton.me> - 0.16.4-2
- Patch to avoid package dependency on modern python

* Wed Dec 21 2022 Mattia Verga <mattia.verga@proton.me> - 0.16.4-1
- Update to 0.16.4

* Wed Dec 21 2022 Mattia Verga <mattia.verga@proton.me> - 0.16.2-1
- Initial import (fedora#2154240)
## END: Generated by rpmautospec
